Event

Struct Event 

#[repr(C)]
pub struct Event { pub time: u64, pub commit_time: u64, pub actor: usize, pub task: SchedulingTask, }
An event that can be scheduled in a simulation. This is used to trigger an actor, or schedule another event.

Fields

time: u64commit_time: u64actor: usizetask: SchedulingTask

Implementations

Source

impl Event

pub fn new( commit_time: u64, time: u64, actor: usize, task: SchedulingTask, ) -> Self

pub fn time(&self) -> u64