Core data structures for simulation including messages, events, and scheduling primitives.
Contains Msg for inter-actor communication, Event for actor scheduling, AntiMsg for
optimistic rollback, and local event/mail systems for efficient time-based scheduling.
Structs
- Event
- An event that can be scheduled in a simulation. This is used to trigger an actor, or schedule another event.
- Local
Scheduler - Thread-local scheduler of a single object type in simulation time.
- Msg
- A
Msgis a direct message between two entities that shares a piece of data of type T
Enums
- Scheduling
Task - A SchedulingTask that an
ActororConnectedActorcan take.