#[repr(C)]pub struct Event {
pub time: u64,
pub commit_time: u64,
pub actor: usize,
pub task: SchedulingTask,
}Expand description
An event that can be scheduled in a simulation. This is used to trigger an actor, or schedule another event.
Fields
time: u64commit_time: u64actor: usizetask: SchedulingTaskImplementations